@@ -246,19 +246,6 @@ class FederationEntityConfiguration(TimeStampedModel):
         self.entity_type = self.type[0]
         super().save(*args, **kwargs)
 
-        if self.entity_type in ENTITY_TYPE_LEAFS:
-            valid_kids = set()
-            for jwk in self.jwks_fed:
-                valid_kids.add(jwk.get("kid", None))
-            
-            for entity,metadata in self.metadata.items():
-                for oidc_jwk in metadata['jwks']['keys']:
-                    if oidc_jwk['kid'] not in valid_kids:
-                        logger.warning(
-                            f"Found a public jwk in {entity} that haven't a valid "
-                            f"jwk {oidc_jwk['kid']} in {self.jwks_fed}."
-                        )
-
     def __str__(self):
         return "{} [{}]".format(
             self.sub, "active" if self.is_active else "--"
@@ -325,6 +312,11 @@ class TrustChain(TimeStampedModel):
         ),
         default=list,
     )
+    jwks = models.JSONField(
+        blank=False,
+        null=False,
+        help_text=_("jwks of this federation entity")
+    )
     metadata = models.JSONField(
         blank=True,
         null=True,
